pro ssws_gevevent, t0, t1, et0, et1, etp, class=class, above=above, threshold=threshold, $
   biggest=biggest, found=found
;
;+
;   Name: ssw_gevvent
;
;   Purpose: goes event times within time range and exceedin optional threshold
;
;   Input Paramters:
;      t0 - start time of range or event time for closest match
;      t1 - optional stop time of range
;
;   Output Parameters:
;      et0,et1,etp - event start,stop,peak (see decode_gev.pro)
;
;   Keyword Parameters:
;      class (output) - GOES class of matching event(s)
;      above (input ) - Lower GOES threshold to consider ('c','m1',..)
;      threshold (input) - synonym for ABOVE
;      biggest (switch) - if set, return largest event in time window
;                         (default are all times in window exceeding ABOVE)
;      found (outut boolean) - true if at least one event returned
;     
;   History:
;      5-Dec-2001 - simple time+threshold -> event times
;                   interface helper routine (WWW pipelines for example)
;   Calls:
;      get_gev, decode_gev and the usual SSW suspects
;-
if keyword_set(threshold) then above=threshold
biggest=keyword_set(biggest)
found=0
closest=0
case 1 of
   data_chk(t0,/undef): begin
         box_message,'No input time range, returning...'
         return
   endcase
   data_chk(t1,/undef): begin
         closest=1
         time_window,t0,xt0,xt1,out='ecs',hours=[-3,3]
   endcase
   else: begin 
      xt0=anytim(t0,/ecs)
      xt1=anytim(t1,/ecs)
   endcase
endcase

gev=get_gev(xt0,xt1)

if data_chk(gev,/struct) then begin 
   decode_gev,gev, et0, et1, etp, ss=ss, out='ecs', above=above, class=class, found=found
   if found then begin 
      case 1 of 
         closest: ss=tim2dset(anytim(etp,/int),anytim(t0,/int)) 
         biggest: begin
            order=sort(class)
            ss=last_nelem(order)   
         endcase
         else: ss=lindgen(n_elements(et0))
      endcase
      et0=et0(ss)
      et1=et1(ss)
      etp=etp(ss)
      class=class(ss)

   endif else box_message,'No events at or above threshold'
endif else box_message,'No GEV events within time window
return
end
